============
pyart.aux_io
============

Input/Output routines.

.. automodule:: pyart.aux_io.sinarame_h5
.. automodule:: pyart.aux_io.d3r_gcpex_nc
.. automodule:: pyart.aux_io.edge_netcdf
.. automodule:: pyart.aux_io.gamic_hdf5
.. automodule:: pyart.aux_io.gamicfile
.. automodule:: pyart.aux_io.odim_h5
.. automodule:: pyart.aux_io.pattern
.. automodule:: pyart.aux_io.radx
.. automodule:: pyart.aux_io.noxp_iphex_nc
.. automodule:: pyart.aux_io.rainbow_wrl
